@@ -60,6 +60,25 @@ aux = {
                 <FechaSolicitud>2020-09-09T01:13:37</FechaSolicitud>
                 <CUPS>ES0291000000000794KT0F</CUPS>
         </Cabecera>
+</MensajeSolicitudInformacionAlRegistroDePS>
+        """
+    },
+    'datacenter': {
+        'url': "https://switching.datacenter.gl/wsdl",
+        'user': "sw_enova_0967",
+        'password': "MmZmZjdh",
+        'file': """
+<MensajeSolicitudInformacionAlRegistroDePS xmlns="http://localhost/elegibilidad">
+        <Cabecera>
+                <CodigoREEEmpresaEmisora>0967</CodigoREEEmpresaEmisora>
+                <CodigoREEEmpresaDestino>0188</CodigoREEEmpresaDestino>
+                <CodigoDelProceso>P0</CodigoDelProceso>
+                <CodigoDePaso>01</CodigoDePaso>
+                <CodigoDeSolicitud>202010303087</CodigoDeSolicitud>
+                <SecuencialDeSolicitud>01</SecuencialDeSolicitud>
+                <FechaSolicitud>2020-09-09T01:13:37</FechaSolicitud>
+                <CUPS>ES0188000006300505QY1F</CUPS>
+        </Cabecera>
 </MensajeSolicitudInformacionAlRegistroDePS>
         """
     }
@@ -67,6 +86,6 @@ aux = {
 
 
 from gestionatr.cli import request_p0
-distri = "endesa"
+distri = "datacenter"
 res = request_p0(aux[distri]['url'], aux[distri]['user'], aux[distri]['password'], aux[distri]['file'])
 print res
